@@ -7,8 +7,17 @@
 post=function(X,...)
 {
     UseMethod("post")
+
 }
 
+### Prototype : entropy(X)
+entropy=function(X,...)
+{
+    UseMethod("entropy")
+}
+
+
+
 post.mmeln=function(X,...,mu=X$param$mu,tau=X$param$tau,sigma=X$param$sigma)
 {
     post=matrix()
@@ -36,3 +45,9 @@ post.mmeln=function(X,...,mu=X$param$mu,tau=X$param$tau,sigma=X$param$sigma)
 }
 
 
+entropy.mmeln=function(X,...)
+{
+    tauij=post(X)
+    -sum(tauij*log(tauij))
+}
+
